@@ -76,7 +76,7 @@ public:
      * This function is used to determinate collision between items
      * @return QPainterPath the new shape of the Bomb
      */
-    QPainterPath shape() const Q_DECL_OVERRIDE;
+    QPainterPath shape() const override;
 
     /**
     * @return the explosion ID
@@ -96,7 +96,7 @@ public:
      */
      void updateAnimationn(int nFrame);
 
-public slots:
+public Q_SLOTS:
 
     /**
      * Updates the graphics after a resize
